============================
Function Reference by Module
============================


****************************************************
Local field potentials (LFPs) and population signals
****************************************************


.. toctree::
    :maxdepth: 1

    reference/signal_processing
    reference/spectral
    reference/causality
    reference/current_source_density


************
Spike trains
************

.. toctree::
    :maxdepth: 2

    reference/statistics

.. toctree::
    :maxdepth: 2

    reference/_spike_train_processing
    reference/_spike_train_patterns

.. toctree::
    :maxdepth: 1

    reference/change_point_detection
    reference/gpfa
.. toctree::
    :maxdepth: 1

    reference/spike_train_surrogates

.. toctree::
    :maxdepth: 2

    reference/spike_train_generation
    

********************************
LFPs and spike trains (combined)
********************************

.. toctree::
    :maxdepth: 1

    reference/sta
    reference/phase_analysis

*******
Kernels
*******

.. toctree::
    :maxdepth: 2

    reference/kernels


*********
Waveforms
*********

.. toctree::
    :maxdepth: 1

    reference/waveform_features

********************************
Alternative data representations
********************************

.. toctree::
    :maxdepth: 1

    reference/conversion

*************
Miscellaneous
*************

.. toctree::
    :maxdepth: 1

    reference/neo_tools
    reference/utils
    reference/pandas_bridge
    reference/parallel
